@@ -13,28 +13,27 @@ Metadata DAG common functions
 """
 import json
 from datetime import datetime, timedelta
-from typing import Any, Callable, Dict, Optional
+from typing import Callable, Optional
 
 from airflow import DAG
 
 from metadata.generated.schema.type import basic
 from metadata.ingestion.models.encoders import show_secrets_encoder
 from metadata.orm_profiler.api.workflow import ProfilerWorkflow
+from metadata.utils.logger import set_loggers_level
 
 try:
     from airflow.operators.python import PythonOperator
 except ModuleNotFoundError:
     from airflow.operators.python_operator import PythonOperator
 
-from airflow_provider_openmetadata.lineage.callback import (
-    failure_callback,
-    success_callback,
-)
 from metadata.generated.schema.entity.services.ingestionPipelines.ingestionPipeline import (
     IngestionPipeline,
 )
 from metadata.generated.schema.metadataIngestion.workflow import (
+    LogLevels,
     OpenMetadataWorkflowConfig,
+    WorkflowConfig,
 )
 from metadata.ingestion.api.workflow import Workflow
 
@@ -48,6 +47,8 @@ def metadata_ingestion_workflow(workflow_config: OpenMetadataWorkflowConfig):
 
     This is the callable used to create the PythonOperator
     """
+    set_loggers_level(workflow_config.workflowConfig.loggerLevel.value)
+
     config = json.loads(workflow_config.json(encoder=show_secrets_encoder))
 
     workflow = Workflow.create(config)
@@ -66,6 +67,9 @@ def profiler_workflow(workflow_config: OpenMetadataWorkflowConfig):
 
     This is the callable used to create the PythonOperator
     """
+
+    set_loggers_level(workflow_config.workflowConfig.loggerLevel.value)
+
     config = json.loads(workflow_config.json(encoder=show_secrets_encoder))
 
     workflow = ProfilerWorkflow.create(config)
@@ -87,17 +91,18 @@ def date_to_datetime(
     return datetime.strptime(str(date.__root__), date_format)
 
 
-def build_default_args() -> Dict[str, Any]:
+def build_workflow_config_property(
+    ingestion_pipeline: IngestionPipeline,
+) -> WorkflowConfig:
     """
-    Build the default_args dict to be passed
-    to the DAG regardless of the airflow_pipeline
-    payload.
+    Prepare the workflow config with logLevels and openMetadataServerConfig
+    :param ingestion_pipeline: Received payload from REST
+    :return: WorkflowConfig
     """
-    return {
-        # Run the lineage backend callbacks to gather the Pipeline info
-        "on_failure_callback": failure_callback,
-        "on_success_callback": success_callback,
-    }
+    return WorkflowConfig(
+        loggerLevel=ingestion_pipeline.loggerLevel or LogLevels.INFO,
+        openMetadataServerConfig=ingestion_pipeline.openMetadataServerConnection,
+    )
 
 
 def build_dag_configs(ingestion_pipeline: IngestionPipeline) -> dict:
@@ -109,7 +114,6 @@ def build_dag_configs(ingestion_pipeline: IngestionPipeline) -> dict:
     return {
         "dag_id": ingestion_pipeline.name.__root__,
         "description": ingestion_pipeline.description,
-        "default_args": build_default_args(),
         "start_date": date_to_datetime(ingestion_pipeline.airflowConfig.startDate),
         "end_date": date_to_datetime(ingestion_pipeline.airflowConfig.endDate),
         "concurrency": ingestion_pipeline.airflowConfig.concurrency,
